==> cdktf-cdktf-provider-databricks-3.0.2.tar.gz: package/lib/repo/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RepoConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#branch Repo#branch}
    */
    readonly branch?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#commit_hash Repo#commit_hash}
    */
    readonly commitHash?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#git_provider Repo#git_provider}
    */
    readonly gitProvider?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#id Repo#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#path Repo#path}
    */
    readonly path?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#tag Repo#tag}
    */
    readonly tag?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#url Repo#url}
    */
    readonly url: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/databricks/r/repo databricks_repo}
*/
export declare class Repo extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_repo";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/databricks/r/repo databricks_repo} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RepoConfig
    */
    constructor(scope: Construct, id: string, config: RepoConfig);
    private _branch?;
    get branch(): string;
    set branch(value: string);
    resetBranch(): void;
    get branchInput(): string | undefined;
    private _commitHash?;
    get commitHash(): string;
    set commitHash(value: string);
    resetCommitHash(): void;
    get commitHashInput(): string | undefined;
    private _gitProvider?;
    get gitProvider(): string;
    set gitProvider(value: string);
    resetGitProvider(): void;
    get gitProviderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _tag?;
    get tag(): string;
    set tag(value: string);
    resetTag(): void;
    get tagInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    get urlInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-databricks-6.0.0.tar.gz: package/lib/repo/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RepoConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#branch Repo#branch}
    */
    readonly branch?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#commit_hash Repo#commit_hash}
    */
    readonly commitHash?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#git_provider Repo#git_provider}
    */
    readonly gitProvider?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#id Repo#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#path Repo#path}
    */
    readonly path?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#tag Repo#tag}
    */
    readonly tag?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#url Repo#url}
    */
    readonly url: string;
    /**
    * sparse_checkout block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#sparse_checkout Repo#sparse_checkout}
    */
    readonly sparseCheckout?: RepoSparseCheckout;
}
export interface RepoSparseCheckout {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#patterns Repo#patterns}
    */
    readonly patterns: string[];
}
export declare function repoSparseCheckoutToTerraform(struct?: RepoSparseCheckoutOutputReference | RepoSparseCheckout): any;
export declare class RepoSparseCheckoutOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RepoSparseCheckout | undefined;
    set internalValue(value: RepoSparseCheckout | undefined);
    private _patterns?;
    get patterns(): string[];
    set patterns(value: string[]);
    get patternsInput(): string[] | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/databricks/r/repo databricks_repo}
*/
export declare class Repo extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_repo";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/databricks/r/repo databricks_repo} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RepoConfig
    */
    constructor(scope: Construct, id: string, config: RepoConfig);
    private _branch?;
    get branch(): string;
    set branch(value: string);
    resetBranch(): void;
    get branchInput(): string | undefined;
    private _commitHash?;
    get commitHash(): string;
    set commitHash(value: string);
    resetCommitHash(): void;
    get commitHashInput(): string | undefined;
    private _gitProvider?;
    get gitProvider(): string;
    set gitProvider(value: string);
    resetGitProvider(): void;
    get gitProviderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _tag?;
    get tag(): string;
    set tag(value: string);
    resetTag(): void;
    get tagInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    get urlInput(): string | undefined;
    private _sparseCheckout;
    get sparseCheckout(): RepoSparseCheckoutOutputReference;
    putSparseCheckout(value: RepoSparseCheckout): void;
    resetSparseCheckout(): void;
    get sparseCheckoutInput(): RepoSparseCheckout | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
